#!/bin/sh 
# This utility install overlay1.img which has the IVSU fix for all 17.X versions

# Signal handler.
SignalTrap()
{
	echo "Received signal.  Update aborting."
	exit 1
}

# In case of error, exit the script with error
function exitWithError
{   
	echo "Exit script with error."
	exit 1
}

# Verify that the application version is for MY17.75PSW2 - BFBF12.9.8 [16350]
function validatebaseversion
{
	if [ -e /fs/rwdata/.Version/JL1T-14G381-AD_Version.inf ]; then
		echo "Base version JL1T-14G381-AD is correct "
	else
		echo "Base version is not JL1T-14G381-AD"
		exitWithError
	fi
}

# Copy, activate and block IVSU
function installoverlay
{
	# Check if Overlay is already present, then just pass through
	if [ -e /fs/images/overlay1.img ]; then
		echo "overlay1.img is already present no need to copy/install the same"
		echo "Pass through"
	else
	# Copy the overlay which has the IVSU binary
		echo "Copy overlay1.img"
		if [ -e /tmp/overlay1.img ]; then
			echo "Copying overlay1.img to /fs/images"
			cp /tmp/overlay1.img /fs/images/overlay1.img.bk
			mv /fs/images/overlay1.img.bk /fs/images/overlay1.img
			if [ $? -ne 0 ]; then
				echo "Failed copying overlay1.img"
				exitWithError
			else
				echo "Success in copying overlay1.img"
				# Copy the version.inf to /fs/rwdata/.version to report part number in $8060
				if [ -e /tmp/HB5T-14G386-ALA_Version.inf ]; then
					cp /tmp/HB5T-14G386-ALA_Version.inf /fs/rwdata/.Version/HB5T-14G386-ALA_Version.inf.bk
					mv /fs/rwdata/.Version/HB5T-14G386-ALA_Version.inf.bk /fs/rwdata/.Version/HB5T-14G386-ALA_Version.inf
					if [ $? -ne 0 ]; then
						clearoverlay
					else
						echo "Part number recorded"
					fi
				else
					clearoverlay
				fi
			fi
			sync
			sync
			sleep 2
			# Wait for the activation of the overlay in next ignition cycle, hence slay APP_SUM
			slay APP_SUM
			# Pop the error and exit the script
			echo "Overlay is installed, Please perform ignition cycle"
			/tmp/ut_coldreboot
		else
			echo "Can't find overlay1.img in this package"
			exitWithError
		fi
	fi
}

# Unable to record part number so clear overlay
function clearoverlay
{
	echo "Unable to record Partnumber"
	rm -rf /fs/images/overlay1.img
	if [ $? -ne 0 ]; then
		echo "Unable to delete copied overlay"
	else
		echo "Cleared copied overlay"
	fi
	sync
	sync
	sleep 1
	exitWithError
}

# Set Signal Trap
trap SignalTrap INT QUIT TERM ABRT STOP

# Set the permission for the bin used in this utility
cd /tmp
chmod 777 /tmp/ut_coldreboot
sync
sync
sleep 1

# Perform apps base version validation
validatebaseversion
# Perform copying APP_SUM
installoverlay
